@@ -1,17 +1,24 @@
 # Classes and functions
-from .package_info import VERSION, GITHUB, PYPI, github
-from .base import Lattice, Poset, Relation
-from .base_generation.exhaustive import iter_all_lattices
+from .package_info import (
+    VERSION,
+    github,
+)
+from .base import (
+    Lattice,
+    Poset,
+    Relation,
+)
+from .base_generation.exhaustive import (
+    iter_all_lattices,)
 from .base_generation.random import (
     random_lattice,
     random_poset,
     random_f,
 )
-from .functional import f_lub, f_glb, f_iter
 
 # Modules
 from . import package_info
-from . import _enum as enum
-from . import functional
+from . import function_iteration
 from .base_methods import validation, graphviz
 from .base_generation import random, exhaustive
+from . import _enum as enum
