@@ -3,6 +3,6 @@ avispa_lattices
 avispa_lattices.utils
 avispa_lattices.base_methods
 avispa_lattices.base_generation
-avispa_lattices.functional
+avispa_lattices.testing
 avispa_lattices.package_info
 '''
\ No newline at end of file
